package com.ruoyi.project.business.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.common.importExcel.excel.helper.BasicTableInfoHelper;
import com.ruoyi.common.importExcel.excel.tempInfo.ParaLibraryExcel;
import com.ruoyi.common.importExcel.excel.tempInfo.ParaLibraryExportHelper;
import com.ruoyi.common.importExcel.excel.tempInfo.ParaSelectExcel;
import com.ruoyi.common.importExcel.utils.ExcelUtils.UploadResult;
import com.ruoyi.project.business.domain.TpAreaParaSelectItem;
import com.ruoyi.project.business.domain.TpParaLibrary;

import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 参数Service接口
 *
 * @author ruoyi
 * @date 2024-04-23
 */
public interface ITpParaLibraryService extends IService<TpParaLibrary> {
    /**
     * 查询参数
     *
     * @param id 参数主键
     * @return 参数
     */
    public TpParaLibrary selectTpParaLibraryById(Long id);

    /**
     * 查询参数列表
     *
     * @param tpParaLibrary 参数
     * @return 参数集合
     */
    public List<TpParaLibrary> selectTpParaLibraryList(TpParaLibrary tpParaLibrary);

    /**
     * 查询参数包的参数
     *
     * @param parabarId 参数包ID
     * @return 参数集合
     */
    public List<TpParaLibrary> selectTpParaLibraryByParabarId(Long parabarId);

    /**
     * 新增参数
     *
     * @param tpParaLibrary 参数
     * @return 结果
     */
    public int insertTpParaLibrary(TpParaLibrary tpParaLibrary);

    /**
     * 修改参数
     *
     * @param tpParaLibrary 参数
     * @return 结果
     */
    public int updateTpParaLibrary(TpParaLibrary tpParaLibrary);

    /**
     * 批量删除参数
     *
     * @param ids 需要删除的参数主键集合
     * @return 结果
     */
    public int deleteTpParaLibraryByIds(Long[] ids);

    /**
     * 删除参数信息
     *
     * @param id 参数主键
     * @return 结果
     */
    public int deleteTpParaLibraryById(Long id);

    /**
     * 修改参数状态
     *
     * @param tpParaLibrary 参数
     * @return 结果
     */
    public int updateParaStatus(TpParaLibrary tpParaLibrary);

    public List<String> insertTpParaLibraryExcel(@NotEmpty List<ParaLibraryExcel> tpParaLibrarys);

    UploadResult<ParaLibraryExcel> checkParaLibrary(BasicTableInfoHelper tableInfo, List<ParaLibraryExcel> list);

    List<ParaLibraryExportHelper> selectTpParaLibraryListExport(TpParaLibrary tpParaLibrary);

    List<ParaLibraryExportHelper> selectModelExport(TpAreaParaSelectItem tpAreaParaSelectItem);
}
